RxConfig

Struct RxConfig 

#[non_exhaustive]
pub struct RxConfig { /* private fields */ }
UART Receive part configuration.

Implementations

Source

impl RxConfig

pub fn with_fifo_full_threshold(self, fifo_full_threshold: u16) -> Self

Assign the given value to the fifo_full_threshold field.

pub fn fifo_full_threshold(&self) -> u16

Threshold level at which the RX FIFO is considered full.

pub fn with_timeout(self, timeout: u8) -> Self

Assign the given value to the timeout field.

pub fn with_timeout_none(self) -> Self

Set the value of timeout to None.

pub fn timeout(&self) -> Option<u8>

Optional timeout value for RX operations.

pub fn with_reported_errors( self, reported_errors: impl Into<EnumSet<RxErrorKind>>, ) -> Self

Available on crate feature unstable only.

Assign the given value to the reported_errors field.

pub fn reported_errors(&self) -> EnumSet<RxErrorKind>

Available on crate feature unstable only.

RX error conditions that read operations should report.

Error conditions not present in this set are cleared and ignored by UART read operations.

pub fn with_discard_erroneous_bytes(self, discard_erroneous_bytes: bool) -> Self

Available on crate feature unstable only.

Assign the given value to the discard_erroneous_bytes field.

pub fn discard_erroneous_bytes(&self) -> bool

Available on crate feature unstable only.

Whether received bytes with UART errors are discarded by the hardware.

When set to true (the default), bytes with UART errors (for example parity or framing errors) are not stored in the RX FIFO. Set this to false to keep those bytes in the RX FIFO. Use Self::with_reported_errors to control whether those error conditions make read operations fail.